@@ -2,6 +2,10 @@ package Net::LDNS::RR::NSEC;
 
 use parent 'Net::LDNS::RR';
 
+sub nxtdname {
+    return $_[0]->next;
+}
+
 1;
 
 =head1 NAME
@@ -20,6 +24,10 @@ A subclass of L<Net::LDNS::RR>, so it has all the methods of that class availabl
 
 Returns the next name.
 
+=item nxtdname()
+
+Alias for C<next()>.
+
 =item typelist()
 
 Returns a string with the typelist. The string has the type names separated by spaces.
@@ -31,4 +39,4 @@ you get a true value back if the record covers it and false if not.
 
 
 
-=back
\ No newline at end of file
+=back
